@@ -1,5 +1,4 @@
 
-use std::cmp::Ordering;
 use std::marker::PhantomData;
 use crate::TopSet;
 
@@ -11,10 +10,10 @@ pub struct TopIter { count: usize }
 pub struct TopIterI<I:IntoIterator> { count: usize, init: I }
 
 #[derive(Clone)]
-pub struct TopIterC<X,C:Fn(&X, &X)->Ordering> { count: usize, cmp: C, item: PhantomData<X> }
+pub struct TopIterC<X,C:Fn(&X, &X)->bool> { count: usize, beat: C, item: PhantomData<X> }
 
 #[derive(Clone)]
-pub struct TopIterIC<I:IntoIterator,C:Fn(&I::Item, &I::Item)->Ordering> { top: TopSet<I::Item,C> }
+pub struct TopIterIC<I:IntoIterator,C:Fn(&I::Item, &I::Item)->bool> { top: TopSet<I::Item,C> }
 
 
 impl Default for TopIter
@@ -37,27 +36,27 @@ impl TopIter
     }
 
     /// Specify the comparison to use
-    pub fn with_compare<X, C:Fn(&X, &X)->Ordering>(self, cmp:C) -> TopIterC<X,C>
+    pub fn with_selector<X, C:Fn(&X, &X)->bool>(self, beat:C) -> TopIterC<X,C>
     {
-        TopIterC { count: self.count, cmp, item: PhantomData::default() }
+        TopIterC { count: self.count, beat, item: PhantomData::default() }
     }
 }
 
 
 impl<I:IntoIterator> TopIterI<I>
 {
-    pub fn with_compare<C:Fn(&I::Item, &I::Item)->Ordering>(self, cmp:C) -> TopIterIC<I,C>
+    pub fn with_selector<C:Fn(&I::Item, &I::Item)->bool>(self, beat:C) -> TopIterIC<I,C>
     {
-        TopIterIC { top: TopSet::with_init(self.count, self.init, cmp) }
+        TopIterIC { top: TopSet::with_init(self.count, self.init, beat) }
     }
 }
 
 
-impl<X,C:Fn(&X, &X)->Ordering> TopIterC<X,C>
+impl<X,C:Fn(&X, &X)->bool> TopIterC<X,C>
 {
     pub fn with_init<I:IntoIterator<Item=X>>(self, init:I) -> TopIterIC<I,C>
     {
-        TopIterIC { top: TopSet::with_init(self.count, init, self.cmp) }
+        TopIterIC { top: TopSet::with_init(self.count, init, self.beat) }
     }
 }
 
@@ -65,17 +64,17 @@ impl<X,C:Fn(&X, &X)->Ordering> TopIterC<X,C>
 impl<I> IntoIterator for TopIterI<I>
     where
         I: IntoIterator,
-        I::Item : Ord
+        I::Item : PartialOrd
 {
     type Item = I::Item;
     type IntoIter = <Vec<I::Item> as IntoIterator>::IntoIter;
 
     fn into_iter(self) -> Self::IntoIter {
-        self.with_compare(<I::Item as Ord>::cmp).into_iter()
+        self.with_selector(<I::Item as PartialOrd>::gt).into_iter()
     }
 }
 
-impl <I:IntoIterator,C:Fn(&I::Item, &I::Item)->Ordering> IntoIterator for TopIterIC<I,C>
+impl <I:IntoIterator,C:Fn(&I::Item, &I::Item)->bool> IntoIterator for TopIterIC<I,C>
 {
     type Item = I::Item;
     type IntoIter = <Vec<I::Item> as IntoIterator>::IntoIter;
@@ -93,15 +92,15 @@ mod tests {
     #[test]
     fn cost()
     {
-        dbg!(TopIter::new(5)
-            .with_compare(|a:&f32, b:&f32 | b.partial_cmp(a).unwrap())
+        dbg!(TopIter::new(3)
+            .with_selector(|a:&f32, b:&f32 | *a < *b)
             .with_init(vec![81.5, 4.5,4.,1.,45.,22.,11.])
             .into_iter()
             .collect::<Vec<_>>());
 
-        dbg!(TopIter::new(5)
+        dbg!(TopIter::new(3)
             .with_init(vec![81.5, 4.5,4.,1.,45.,22.,11.])
-            .with_compare(|a, b| a.partial_cmp(b).unwrap())
+            .with_selector(|a, b| *a > *b)
             .into_iter()
             .collect::<Vec<_>>());
     }
